<?php
/* Copyright (C) 2016-2017		Eric GROULT			<eric@code42.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *   	\file       event/index.php
 *		\ingroup    event
 *		\brief      Index page of module event
 */

$res=0;
$msg = '';
$error = 0;
if (! $res && file_exists("../../main.inc.php")) $res=include("../../main.inc.php");
if (! $res && file_exists("../../../main.inc.php")) $res=include("../../../main.inc.php"); // for curstom directory

if (! $res) die("Include of main fails");
require_once DOL_DOCUMENT_ROOT."/core/lib/admin.lib.php";
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT."/contrat/class/contrat.class.php";
require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
include("../core/function.php");
include("../core/populate.php");

/**
 * Activate services of a contract
 *
 * @param   Contrat     $contract       A Contrat object
 * @return  int                         < 0 on error, > 0 on success
 */
function activateServices($contract)
{
    global $user;

    $contract->fetch_lines();
    $i = 0;
    while ($i < count($contract->lines))
    {
        $res = $contract->active_line($user, $contract->lines[$i]->id, date('Y-m-d H:i:s', $contract->lines[0]->date_ouverture_prevue),
            date('Y-m-d H:i:s', $contract->lines[$i]->date_fin_validite));
        if ($res < 0)
            return -1;

        $i++;
    }
    return 0;
}

/**
 * Create services for a contract
 *
 * @param   Contrat     $contract       A Contrat object
 * @return  int                         < 0 on error, > 0 on success
 */
function createServices($contract)
{
    $tz = new DateTimeZone('Europe/Paris');
    $date_start = new DateTime('2018-04-07 17:00:00', $tz);
    $date_end = new DateTime('2018-04-08 17:00:00', $tz);
    $res = $contract->addline(
        'Service de test code 42',  //desc
        100.00,                     //puht
        1,                          //qty
        20.00,                      //txtva
        0,                          //txlocaltax1
        0,                          //txlocaltax2
        0,                          //fk_product
        0,                          //remise_percent
        $date_start->format('Y-m-d H:i:s'),
        $date_end->format('Y-m-d H:i:s')
    );
    if ($res > 0)
    {
        $res = $contract->addline(
            'Service de test 2 code 42',  //desc
            10.00,                     //puht
            1,                          //qty
            20.00,                      //txtva
            0,                          //txlocaltax1
            0,                          //txlocaltax2
            0,                          //fk_product
            0,                          //remise_percent
            $date_start->format('Y-m-d H:i:s'),
            $date_end->format('Y-m-d H:i:s')
        );
    }

    return $res;
}

/**
 * Create and validate a contract
 *
 * @param   User        $user       The object given by dolibarr global (global $user)
 * @param   Database    $db         The object given by dolibarr global (global $db)
 * @return  Contrat                 null on error, Contrat object on success
 */
function createValidateContract($user, $db)
{
    $contract = new Contrat($db);

    $contract->socid = 189; //id code42 neocenter database
    $contract->date_contrat	= date('Y-m-d H:i:s'); //date d'aujourd'hui
    $contract->commercial_suivi_id = 1; //id admin
    $contract->commercial_signature_id = 1;
    $contract->note_public = "Contrat de test code42";
    $contract->note_private = "Contrat de test code42";

    if ($contract->create($user) > 0 && $contract->validate($user) > 0)
        return $contract;

    return null;
}

/**
 * Create a contract for testing and redirect to index page if all is ok
 *
 * @return int                                      < 0 on error, > 0 on success
 */
function createTest()
{
    global $user, $db;

    $contract = createValidateContract($user, $db);
    if ($contract == null) {
        echo 'Can\'t create or validate the contract';
        return -1;
    }
    if (createServices($contract) < 0) {
        echo 'Can\'t create services';
        $contract->delete($user);
        return -1;
    }
    if (activateServices($contract) < 0) {
        echo 'Can\'t activate services';
        $contract->delete($user);
        return -1;
    }
    header("Location: ".$_SERVER['PHP_SELF']);
    return 1;
}

$page_name = "contratplusSetup";
$langs->load("contratplus@contratplus");

$form = new Form($db);

$usehm=(!empty($conf->global->MAIN_USE_HOURMIN_IN_DATE_RANGE) ? $conf->global->MAIN_USE_HOURMIN_IN_DATE_RANGE : 0);

$supplier = (!empty($conf->global->CONTRATPLUS_SUPPLIER_CONTRACT) ? $conf->global->CONTRATPLUS_SUPPLIER_CONTRACT : 0);

/*
 * Actions
*/

if (GETPOST('action','alpha') == 'setvar') {

	// ContratPlusDateStart
	$contratplus_date_start=dol_mktime(0, 0, 0,GETPOST('CONTRATPLUS_DATE_STARTmonth'),GETPOST('CONTRATPLUS_DATE_STARTday'),GETPOST('CONTRATPLUS_DATE_STARTyear'));
	$res = dolibarr_set_const($db, 'CONTRATPLUS_DATE_START', $contratplus_date_start,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	// ContratPlusDateEnd
	$contratplus_date_end=dol_mktime(0, 0, 0,GETPOST('CONTRATPLUS_DATE_ENDmonth'),GETPOST('CONTRATPLUS_DATE_ENDday'),GETPOST('CONTRATPLUS_DATE_ENDyear'));
	$res = dolibarr_set_const($db, 'CONTRATPLUS_DATE_END', $contratplus_date_end,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	if ($contratplus_date_start > $contratplus_date_end) {
        $error++;
        $msg = $langs->trans("ErrorDate");
    }

	// ContratPlusBillDate
	$contratplus_bill_date=dol_mktime(0, 0, 0,GETPOST('CONTRATPLUS_BILL_DATEmonth'),GETPOST('CONTRATPLUS_BILL_DATEday'),GETPOST('CONTRATPLUS_BILL_DATEyear'));
	$res = dolibarr_set_const($db, 'CONTRATPLUS_BILL_DATE', $contratplus_bill_date,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	// ContratPlusDateBillNote
	$contratplus_bill_note=GETPOST('CONTRATPLUS_BILL_NOTE','alpha');
	$res = dolibarr_set_const($db, 'CONTRATPLUS_BILL_NOTE', $contratplus_bill_note,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	// ContratPlusDateBillNotePrivate
	$contratplus_bill_note_private=GETPOST('CONTRATPLUS_BILL_NOTE_PRIVATE','alpha');
	$res = dolibarr_set_const($db, 'CONTRATPLUS_BILL_NOTE_PRIVATE', $contratplus_bill_note_private,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	// ContratplusCompteDefaut
	$contratplus_compte_defaut=GETPOST('CONTRATPLUS_COMPTE_DEFAUT','alpha');
	$res = dolibarr_set_const($db, 'CONTRATPLUS_COMPTE_DEFAUT', $contratplus_compte_defaut,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	// ContratplusCompteDefaut
	$contratplus_bypass=GETPOST('CONTRATPLUS_BYPASS','int');
	$res = dolibarr_set_const($db, 'CONTRATPLUS_BYPASS', $contratplus_bypass,'',0,'',$conf->entity);
	if (! $res > 0) $error++;

	$contratplus_model_customer = GETPOST('multimodelcustomer');
    $res = dolibarr_set_const($db, 'CONTRATPLUS_MODEL_CUSTOMER', $contratplus_model_customer,'',0,'',$conf->entity);
    if (! $res > 0) $error++;

    $contratplus_model_supplier = GETPOST('multimodelsupplier');
    $res = dolibarr_set_const($db, 'CONTRATPLUS_MODEL_SUPPLIER', $contratplus_model_supplier,'',0,'',$conf->entity);
    if (! $res > 0) $error++;

	//TEST ERROR
	if (! $error && $msg == '') {
		$msg = $langs->trans("SetupSaved");
	}
	else if ($msg == '') {
		$msg = $langs->trans("Error");
	}
}

if (GETPOST('action') == 'update') {
    $value_select = GETPOST('select');

    if (intval($value_select) > 2)
        $value_select = '0';

    /* execution de la requete */
    $sqlupd = "UPDATE llx_contratplus SET active = '".$value_select."' WHERE name = 'OPTION'";
    dol_syslog(':: - '.$page_name.' '.$sqlupd, LOG_DEBUG);
    $db->query($sqlupd);
    $msg = $langs->trans("SetupSaved");
    header("Location: ".$_SERVER['PHP_SELF']);
}

if (GETPOST('action') == 'setsupplier') {
    $status = GETPOST('status');
    $res = dolibarr_set_const($db, 'CONTRATPLUS_SUPPLIER_CONTRACT', $status);
    if (! $res < 0) {
        $error++;
        $msg = $langs->trans('Error');
    }
    else
        $msg = $langs->trans('SetupSaved');
    header("Location: ".$_SERVER['PHP_SELF']);
}

// Check if test mode is activated
if ($conf->global->MAIN_FEATURES_LEVEL=='3' && GETPOST('action') == 'create_test')
    createTest();

if ($conf->global->MAIN_FEATURES_LEVEL=='3' && GETPOST('action') == 'populate_date_end')
    populateDb();

if ($conf->global->MAIN_FEATURES_LEVEL=='3' && GETPOST('action') == 'clean_date_end')
    cleanDateEnd();

/***************************************************
 * VIEW
*
* Put here all code to build page
****************************************************/
$morejs = array("/contratplus/js/contratPlus.js");
llxHeader('', $langs->trans("ContratPlusSetup"), '', '', '', '', $morejs, '', 0, 0);

dol_fiche_head();

print load_fiche_titre($langs->trans('ContratPlusInfo'));

print '<form name="ContratPlusInfo">';
print '<table class="border" width="100%">';
print '<tr class="liste_titre">';
print '<td colspan="2">'.$langs->trans("AdminManageRuleInvitation").'</td>';
print '</tr>';

print '<tr class="impair"><td>'.$langs->trans('ContratPlusDateStart');
print '</td><td>';
$form->select_date($conf->global->CONTRATPLUS_DATE_START,'CONTRATPLUS_DATE_START',$usehm,$usehm,'0','ContratPlusInfo','1','');
print '</td></tr>';

print '<tr class="pair"><td>'.$langs->trans('ContratPlusDateEnd');
print '</td><td>';
$form->select_date($conf->global->CONTRATPLUS_DATE_END,'CONTRATPLUS_DATE_END',$usehm,$usehm,'0','ContratPlusInfo','1','');
print '</td></tr>';

print '<tr class="impair"><td>'.$langs->trans('ContratPlusBillDate');
print '</td><td>';
$form->select_date($conf->global->CONTRATPLUS_BILL_DATE,'CONTRATPLUS_BILL_DATE',$usehm,$usehm,'0','ContratPlusInfo','1','');
print '</td></tr>';

print '<tr class="pair"><td>'.$langs->trans('ContratPlusBillNote');
print '</td><td>';
$doleditor = new DolEditor('CONTRATPLUS_BILL_NOTE', $conf->global->CONTRATPLUS_BILL_NOTE,
    '', 160, '', '', true, true, $conf->global->FCKEDITOR_ENABLE_PRODUCTDESC, 4, 80);
$doleditor->Create();
print '</td></tr>';

print '<tr class="pair"><td>'.$langs->trans('ContratPlusBillNotePrivate');
print '</td><td>';
$doleditor = new DolEditor('CONTRATPLUS_BILL_NOTE_PRIVATE', $conf->global->CONTRATPLUS_BILL_NOTE_PRIVATE,
    '', 160, '', '', true, true, $conf->global->FCKEDITOR_ENABLE_PRODUCTDESC, 4, 80);
$doleditor->Create();
print '</td></tr>';

print '<tr class="impair"><td>'.$langs->trans('ContratplusCompteDefaut');
print '</td><td>';
$form->select_comptes($conf->global->CONTRATPLUS_COMPTE_DEFAUT, 'CONTRATPLUS_COMPTE_DEFAUT', 0, '', 1);
print '</td></tr>';

print '<tr><td>' . $langs->trans('ModelPDFCustomer') . '</td>';
print '<td colspan="2">';
include_once DOL_DOCUMENT_ROOT . '/core/modules/facture/modules_facture.php';
$liste = ModelePDFFactures::liste_modeles($db);
$model = isset($conf->global->CONTRATPLUS_MODEL_CUSTOMER) ? $conf->global->CONTRATPLUS_MODEL_CUSTOMER : $conf->global->FACTURE_ADDON_PDF;
print $form->selectarray('multimodelcustomer', $liste, $model);
print "</td></tr>";

if ($conf->global->CONTRATPLUS_SUPPLIER_CONTRACT)
{
    print '<tr><td>' . $langs->trans('ModelPDFSupplier') . '</td>';
    print '<td colspan="2">';
    include_once DOL_DOCUMENT_ROOT.'/core/modules/supplier_invoice/modules_facturefournisseur.php';
    $liste = ModelePDFSuppliersInvoices::liste_modeles($db);
    $model = isset($conf->global->CONTRATPLUS_MODEL_SUPPLIER) ?
        $conf->global->CONTRATPLUS_MODEL_SUPPLIER : $conf->global->INVOICE_SUPPLIER_ADDON_PDF;
    print $form->selectarray('multimodelsupplier', $liste, $model);
    print "</td></tr>";

}

// Masquage group
if (isset($conf->global->CONTRATPLUS_BYPASS))
{
	if ($conf->global->CONTRATPLUS_BYPASS > 0) {
		$checkedYes='checked="checked"';
		$checkedNo='';
	}else {
		$checkedYes='';
		$checkedNo='checked="checked"';
	}
}
else
{
	if (GETPOST('contratplus_bypass','int')>0) {
		$checkedYes='checked="checked"';
		$checkedNo='';
	}else {
		$checkedYes='';
		$checkedNo='checked="checked"';
	}
}

print '<tr><td colspan="">'.$langs->trans('contratplus_bypass');
print '</td>';
print '<td>';
print '<input type="radio" id="contratplus_bypass_confirm" name="CONTRATPLUS_BYPASS" value="1" '.$checkedYes.'/> <label for="contratplus_bypass_confirm">'.$langs->trans('Yes').'</label>';
print '<br/>';
print '<input type="radio" id="contratplus_bypass_cancel" name="CONTRATPLUS_BYPASS" '.$checkedNo.' value="-1"/> <label for="contratplus_bypass_cancel">'.$langs->trans('No').'</label>';
print '</td>';
print '</tr>';

print '<input type="hidden" name="action" value="setvar" />';
print '<tr class="pair"><td colspan="3" align="center"><input type="submit" class="button" value="'.$langs->trans("Save").'"></td>';
print '</table>';
print '</form>';

/* trouver l'option choisie*/
$sql = "SELECT llx_contratplus.active FROM llx_contratplus WHERE llx_contratplus.name = 'OPTION'";
$resql = $db->query($sql);
$res = $resql->fetch_assoc();
$option = $res['active'];
						
print '<br />'.load_fiche_titre("Option renouvellement simple");

print '<form name="update_option">';
print '<table class="noborder" width="100%">';
print '<tr class="liste_titre">';
print '<td>OPTION : Choisir une option pour le renouvellement</td>';
print '<td>Description</td></tr>';

// Code 42 - On désactive la fonction envoi par mail
// while ($i < 4)
// Code 42 - End
for ($i = 0; $i < 4; $i++)
{
	($i % 2 == 0) ? print '<tr class="pair"><td>&nbsp;' : print '<tr class="impair"><td>&nbsp;';
	$name = "Option " . $i;

	if ($i == $option)
		print '<input type="radio" name="select" value="'.$i.'"" checked="checked"> '.$name.' <br/>';
	else
    {
        $input = '<input type="radio" name="select" value="'.$i.'""';
        if ($i == 3)
            $input .= ' disabled';
        $input .= '> '.$name.' <br/>';
        print  $input;
    }

	print '</td>';

	$str = 'Option' . strval($i);
	print '<td>'.$langs->trans($str).'</td>';
}
print '</tr>';
print '<tr><td colspan="3">';
print '<input type="hidden" name="action" value="update">';
print '<div align="center"><p><input type="submit" value="'.$langs->trans("Modify").'" class="button"></p></div>';
print '</td>';
print '</table>';
print '</form><br />';


/* START Supplier invoice */
print '<table class="noborder" width="100%">';
print '<tr class="liste_titre">';
print '<td colspan="2">'.$langs->trans('SupplierOption').'</td>';
print '</tr>';
print '<tr class="pair">';
print '<td>' . $langs->trans('ActivateSupplierInvoiceCreation') . '</td>';

if ($supplier != 0)
{
    print '<td><a href="'.$_SERVER['PHP_SELF'].'?action=setsupplier&status=0">';
    print img_picto($langs->trans("Activated"),'switch_on');
    print '</a></td>';
}
else
{
    print '<td><a href="'.$_SERVER['PHP_SELF'].'?action=setsupplier&status=1">';
    print img_picto($langs->trans("Disabled"),'switch_off');
    print '</a></td>';
}
print '</tr>';
print '</table><br />';
/* END Supplier invoice */


if ($conf->global->MAIN_FEATURES_LEVEL=='3')
{
    print load_fiche_titre($langs->trans('Debug'));
    print '<table class="noborder" width="100%">';

    print '<tr class="impair"><td>'.$langs->trans('SQL UDP');
    print '</td><td>';
    $sqlupd;
    print '</td></tr>';

    print '<tr class="pair"><td>'.$langs->trans('SQL UPDBYP');
    print '</td><td>';
    $sqlupdbyp;
    print '</td></tr>';

    print '<tr class="impair"><td>'.$langs->trans('SQL SELECT');
    print '</td><td>';
    $sql;
    print '</td></tr>';

    print '<tr class="pair"><td>'.$langs->trans('select');
    print '</td><td>';
    GETPOST('select');
    print '</td></tr>';

    print '<tr class="impair"><td>'.$langs->trans('contratplus_date_start');
    print '</td><td>';
    $contratplus_date_start;
    print '</td></tr>';

    print '<tr class="pair"><td>'.$langs->trans('contratplus_date_end');
    print '</td><td>';
    $contratplus_date_end;
    print '</td></tr>';

    print '<tr class="impair"><td>'.$langs->trans('contratplus_bill_date');
    print '</td><td>';
    $contratplus_bill_date;
    print '</td></tr>';

    print '<tr><td colspan="2">';
    print '<div align="center"><p>' .
        '<a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?action=create_test">' . $langs->trans("CreateTest") . '</a>' .
        '<a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?action=populate_date_end">' . $langs->trans("PopulateDateEnd") . '</a>' .
        '<a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?action=clean_date_end">' . $langs->trans("CleanDateEnd") . '</a>' .
        '</p></div>';
    print '<div align="center"><p></p></div>';
    print '</td>';

    print '</table>';
}

dol_htmloutput_mesg($msg, '', $error == 0 ? 'ok' : 'error' );

dol_fiche_end();

llxFooter();
